==> iogrind-0.0.1.tar.gz: iogrind-0.0.1/disksim-3.0/libparam/libparam.tab.h <==
/* A Bison parser, made by GNU Bison 2.1.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     LBRACE = 258,
     RBRACE = 259,
     SEMI = 260,
     EQUAL = 261,
     TRUE = 262,
     FALSE = 263,
     DECINT = 264,
     HEXINT = 265,
     FLOAT = 266,
     STRING = 267,
     LBRAK = 268,
     RBRAK = 269,
     COMMA = 270,
     QU = 271,
     COLON = 272,
     NEWLINE = 273,
     SOURCE = 274,
     DOTDOT = 275,
     AS = 276,
     INSTANTIATE = 277,
     TOPOLOGY = 278
   };
#endif
/* Tokens.  */
#define LBRACE 258
#define RBRACE 259
#define SEMI 260
#define EQUAL 261
#define TRUE 262
#define FALSE 263
#define DECINT 264
#define HEXINT 265
#define FLOAT 266
#define STRING 267
#define LBRAK 268
#define RBRAK 269
#define COMMA 270
#define QU 271
#define COLON 272
#define NEWLINE 273
#define SOURCE 274
#define DOTDOT 275
#define AS 276
#define INSTANTIATE 277
#define TOPOLOGY 278




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 55 "libparam.y"
typedef union YYSTYPE {
  double d;
  int i;
  char *s;

  struct lp_block *b;
  struct { struct lp_block **b; int blen; } blocks;

  struct lp_param *p;
  struct { struct lp_param **p; int plen; } params;

  struct lp_list *l;

  struct lp_value *v;

  struct { struct lp_topospec *l; int len; } topo;
  struct lp_inst *inst;
} YYSTYPE;
/* Line 1447 of yacc.c.  */
#line 103 "libparam.tab.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE libparamlval;

==> iogrind-0.0.3.tar.gz: iogrind-0.0.3/disksim-3.0/libparam/libparam.tab.h <==
/* A Bison parser, made by GNU Bison 2.3.  */

/* Skeleton interface for Bison's Yacc-like parsers in C

   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     LBRACE = 258,
     RBRACE = 259,
     SEMI = 260,
     EQUAL = 261,
     TRUE = 262,
     FALSE = 263,
     DECINT = 264,
     HEXINT = 265,
     FLOAT = 266,
     STRING = 267,
     LBRAK = 268,
     RBRAK = 269,
     COMMA = 270,
     QU = 271,
     COLON = 272,
     NEWLINE = 273,
     SOURCE = 274,
     DOTDOT = 275,
     AS = 276,
     INSTANTIATE = 277,
     TOPOLOGY = 278
   };
#endif
/* Tokens.  */
#define LBRACE 258
#define RBRACE 259
#define SEMI 260
#define EQUAL 261
#define TRUE 262
#define FALSE 263
#define DECINT 264
#define HEXINT 265
#define FLOAT 266
#define STRING 267
#define LBRAK 268
#define RBRAK 269
#define COMMA 270
#define QU 271
#define COLON 272
#define NEWLINE 273
#define SOURCE 274
#define DOTDOT 275
#define AS 276
#define INSTANTIATE 277
#define TOPOLOGY 278




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
#line 55 "libparam.y"
{
  double d;
  int i;
  char *s;

  struct lp_block *b;
  struct { struct lp_block **b; int blen; } blocks;

  struct lp_param *p;
  struct { struct lp_param **p; int plen; } params;

  struct lp_list *l;

  struct lp_value *v;

  struct { struct lp_topospec *l; int len; } topo;
  struct lp_inst *inst;
}
/* Line 1489 of yacc.c.  */
#line 114 "libparam.tab.h"
	YYSTYPE;
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE libparamlval;
